pub enum TranslationError {
LegFailed {
leg_index: usize,
segment_index: u64,
leg_source: CuratedLanguage,
leg_target: CuratedLanguage,
model_id: String,
source: TranslationModelError,
},
}Expand description
A typed failure while executing an already validated translation plan.
Variants
LegFailed
A model leg failed while translating a source segment.
Fields

leg_source: CuratedLanguageSource language of the failed leg.

leg_target: CuratedLanguageTarget language of the failed leg.

source: TranslationModelErrorProvider failure that stopped execution.